@@ -40,7 +40,7 @@
 
 #include "gpm-common.h"
 #include "gpm-conf.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 #include "gpm-cell-unit.h"
 #include "gpm-warnings.h"
 
@@ -82,7 +82,7 @@ gpm_warnings_get_state_time (GpmWarnings  *warnings,
 {
 	if (unit->time_discharge == 0) {
 		/* this is probably an error condition */
-		gpm_warning ("time zero, something's gone wrong");
+		egg_warning ("time zero, something's gone wrong");
 		return GPM_WARNINGS_NONE;
 	}
 	if (unit->time_discharge <= warnings->priv->action_time) {
@@ -101,7 +101,7 @@ gpm_warnings_get_state_percentage (GpmWarnings  *warnings,
 {
 	if (unit->percentage == 0) {
 		/* this is probably an error condition */
-		gpm_warning ("percentage zero, something's gone wrong");
+		egg_warning ("percentage zero, something's gone wrong");
 		return GPM_WARNINGS_NONE;
 	}
 	if (unit->percentage <= warnings->priv->action_percentage) {
@@ -151,7 +151,7 @@ gpm_warnings_get_state (GpmWarnings  *warnings,
 		type = gpm_warnings_get_state_percentage (warnings, unit);
 
 	} else if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY &&
-		   warnings->priv->use_time_primary == TRUE) {
+		   warnings->priv->use_time_primary) {
 
 		type = gpm_warnings_get_state_time (warnings, unit);
 
@@ -170,22 +170,6 @@ gpm_warnings_get_state (GpmWarnings  *warnings,
 	return type;
 }
 
-/**
- * gpm_warnings_constructor:
- **/
-static GObject *
-gpm_warnings_constructor (GType type,
-			 guint n_construct_properties,
-			 GObjectConstructParam *construct_properties)
-{
-	GpmWarnings *warnings;
-	GpmWarningsClass *klass;
-	klass = GPM_WARNINGS_CLASS (g_type_class_peek (GPM_TYPE_WARNINGS));
-	warnings = GPM_WARNINGS (G_OBJECT_CLASS (gpm_warnings_parent_class)->constructor
-			      		     (type, n_construct_properties, construct_properties));
-	return G_OBJECT (warnings);
-}
-
 /**
  * gpm_warnings_finalize:
  **/
@@ -227,7 +211,6 @@ gpm_warnings_class_init (GpmWarningsClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize	   = gpm_warnings_finalize;
-	object_class->constructor  = gpm_warnings_constructor;
 
 	g_type_class_add_private (klass, sizeof (GpmWarningsPrivate));
 }
@@ -262,10 +245,10 @@ gpm_warnings_init (GpmWarnings *warnings)
 	/* We can disable this if the ACPI BIOS is broken, and the
 	   time_remaining is therefore inaccurate or just plain wrong. */
 	gpm_conf_get_bool (warnings->priv->conf, GPM_CONF_USE_TIME_POLICY, &warnings->priv->use_time_primary);
-	if (warnings->priv->use_time_primary == TRUE) {
-		gpm_debug ("Using per-time notification policy");
+	if (warnings->priv->use_time_primary) {
+		egg_debug ("Using per-time notification policy");
 	} else {
-		gpm_debug ("Using percentage notification policy");
+		egg_debug ("Using percentage notification policy");
 	}
 }
 
